summaryrefslogtreecommitdiff
path: root/postprocess
diff options
context:
space:
mode:
authorThorsten Behrens <Thorsten.Behrens@CIB.de>2020-07-06 03:01:51 +0200
committerThorsten Behrens <Thorsten.Behrens@CIB.de>2020-07-10 01:34:54 +0200
commit493ae7a6bb0c3ad50615db0090e7ae8d391bc327 (patch)
tree9f60f522f1ff9dde6a8131d155654f4d47b37fd0 /postprocess
parent005f5db47b8e1bbd7ebddee92009be072e835fd5 (diff)
replace usage of blacklist with denylist
.. and a few cases of instead doing blacklist->excludelist where that made more sense. Background and motivation: https://tools.ietf.org/html/draft-knodel-terminology-02 [API CHANGE] officecfg::Office::Canvas::DeviceBlacklist -> DeviceDenylist [API CHANGE] officecfg::Office::Canvas::BlacklistCurrentDevice -> DenylistCurrentDevice [API CHANGE] officecfg::Office::Common::Misc::OpenCLBlackList -> OpenCLDenyList Change-Id: Ia35e25496bf0cc0692d5de4cb66bfc232d3a869e Reviewed-on: https://gerrit.libreoffice.org/c/core/+/98180 Tested-by: Thorsten Behrens <Thorsten.Behrens@CIB.de> Reviewed-by: Thorsten Behrens <Thorsten.Behrens@CIB.de>
Diffstat (limited to 'postprocess')
-rw-r--r--postprocess/qa/services.cxx16
1 files changed, 8 insertions, 8 deletions
diff --git a/postprocess/qa/services.cxx b/postprocess/qa/services.cxx
index 0806fc14e987..282197acab52 100644
--- a/postprocess/qa/services.cxx
+++ b/postprocess/qa/services.cxx
@@ -122,7 +122,7 @@ private:
};
void Test::test() {
// On Windows, blacklist the com.sun.star.comp.report.OReportDefinition
// implementation (reportdesign::OReportDefinition in
// reportdesign/source/core/api/ReportDefinition.cxx), as it spawns a thread
// that forever blocks in SendMessageW when no VCL event loop is running
@@ -136,12 +136,12 @@ void Test::test() {
// WorkWindow::ImplInit -> ImplBorderWindow::ImplBorderWindow ->
// ImplBorderWindow::ImplInit -> Window::ImplInit ->
// WinSalInstance::CreateFrame -> ImplSendMessage -> SendMessageW):
- std::vector<OUString> blacklist;
- blacklist.emplace_back("com.sun.star.comp.report.OReportDefinition");
+ std::vector<OUString> denylist;
+ denylist.emplace_back("com.sun.star.comp.report.OReportDefinition");
// <https://bugs.documentfoundation.org/show_bug.cgi?id=89343>
// "~SwXMailMerge() goes into endless SwCache::Check()":
- blacklist.emplace_back("SwXMailMerge");
+ denylist.emplace_back("SwXMailMerge");
css::uno::Reference<css::container::XContentEnumerationAccess> enumAcc(
m_xContext->getServiceManager(), css::uno::UNO_QUERY_THROW);
@@ -263,8 +263,8 @@ void Test::test() {
}
std::vector<css::uno::Reference<css::lang::XComponent>> comps;
for (auto const & i: impls) {
- if (std::find(blacklist.begin(), blacklist.end(), i.first)
- == blacklist.end())
+ if (std::find(denylist.begin(), denylist.end(), i.first)
+ == denylist.end())
{
if (i.second.constructors.empty()) {
if (i.second.accumulationBased) {
@@ -458,7 +458,7 @@ void Test::createInstance(
}
}
if (!propsinfo->hasPropertyByName(prop->getName())) {
- static std::set<std::pair<OUString, OUString>> const blacklist{
+ static std::set<std::pair<OUString, OUString>> const denylist{
{"com.sun.star.comp.chart.DataSeries", "BorderDash"},
{"com.sun.star.comp.chart2.ChartDocumentWrapper", "UserDefinedAttributes"},
{"com.sun.star.comp.dbu.OColumnControlModel", "Tabstop"},
@@ -485,7 +485,7 @@ void Test::createInstance(
{"com.sun.star.comp.report.OFormattedField", "TextLineColor"},
{"com.sun.star.comp.report.OFormattedField", "TreatAsNumber"},
{"stardiv.Toolkit.UnoControlRoadmapModel", "Interactive"}};
- if (blacklist.find({implementationName, prop->getName()}) != blacklist.end()) {
+ if (denylist.find({implementationName, prop->getName()}) != denylist.end()) {
continue;
}
CPPUNIT_ASSERT_MESSAGE(
@@ -122,7 +122,7 @@ private:
};
void Test::test() {
- // On Windows, blacklist the com.sun.star.comp.report.OReportDefinition
+ // On Windows, denylist the com.sun.star.comp.report.OReportDefinition
// implementation (reportdesign::OReportDefinition in
// reportdesign/source/core/api/ReportDefinition.cxx), as it spawns a thread